@@ -20,7 +20,7 @@ def get_resource_type(obj):
     return " ".join(case_delineated_words)
 
 
-def settings_str_from(obj, exclude_attrs=ATTRS_TO_EXCLUDE, pop_name=True):
+def settings_str_from(obj, exclude_attrs=ATTRS_TO_EXCLUDE):
     d = copy.deepcopy(obj.__dict__)
     settings = []
     for k, v in d.items():
@@ -34,5 +34,5 @@ def settings_str_from(obj, exclude_attrs=ATTRS_TO_EXCLUDE, pop_name=True):
                 elif isinstance(v, (bool, int)):
                     settings.append(f"{k}={v}")
                 else:
-                    settings.append(f"{k}='{v.name}'")
+                    settings.append(f"{k}='{v.name.upper()}'")
     return " ".join(settings)
